pytest_xdist: Pytest xdist plugin for distributed testing, most importantly across multiple CPUs
================================================================================================

Description
-----------

Pytest xdist plugin for distributed testing, most importantly across multiple CPUs

License
-------

MIT

Upstream Contact
----------------

https://pypi.org/project/pytest-xdist/

